@@ -71,7 +71,8 @@ bool kloghamlib::init(){
 		myport.parm.serial.handshake = RIG_HANDSHAKE_NONE;
 //		cout << "KlogHamlib::init - 7" << endl;
 		//strncpy(myport.pathname, SERIAL_PORT, FILPATHLEN);
-		strncpy(myport.pathname, serialPort, FILPATHLEN);
+//		strncpy(myport.pathname, serialPort, FILPATHLEN);
+                serialPort = myport.pathname;//, FILPATHLEN);
 //		cout << "KlogHamlib::init - 8" << endl;
 		// rig_load_all_backends();
 		// myrig_model = rig_probe(&myport);
@@ -86,7 +87,8 @@ bool kloghamlib::init(){
 			//     exit(1); // whoops! something went wrong (mem alloc?) 
 		}
 //		cout << "KlogHamlib::init - 10" << endl;
-		strncpy(radio->state.rigport.pathname,serialPort,FILPATHLEN);
+//		strncpy(radio->state.rigport.pathname,serialPort,FILPATHLEN);
+                serialPort = radio->state.rigport.pathname;//,FILPATHLEN);
 //		cout << "KlogHamlib::init - 10.1" << endl;
 		retcode = rig_open(radio);
 //		cout << "KlogHamlib::init - 10.2" << endl;
