@@ -21,13 +21,15 @@
 *  You should have received a copy of the GNU General Public License        *
 *  along with this program; if not, write to the Free Software              *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA*
- *****************************************************************************/ 
+ *****************************************************************************/
 #ifndef WORKEDCALLS_H
 #define WORKEDCALLS_H
-#include <qvaluelist.h>
-#include <qstring.h>
-#include <qmap.h>
+#include <QList>
+#include <QString>
+#include <QMap>
+#include <QDebug>
 #include "calls.h"
+//TODO:
 /* IMPORTANT NOTE !!
   Maybe just a table with a CALL <-> "array of numbers" with the QSOs of
   the calls would be OK instead of saving all the data related to every
@@ -39,27 +41,27 @@
 class WorkedCalls{
 public:
 
-	WorkedCalls();
-	~WorkedCalls();
+    WorkedCalls();
+    ~WorkedCalls();
 
 //	New functions and optimizations
 
-	int addCall(const QString& workedCall, const int tnum);
-	int findCall(const QString& workedCall); // 0 or the number of the QSO
+    int addCall(const QString& workedCall, const int tnum);
+    int findCall(const QString& workedCall); // 0 or the number of the QSO
 
 private:
-	typedef QValueList<Calls> TheWorkedCalls;
-	TheWorkedCalls workedCalls;
+    typedef QList<Calls> TheWorkedCalls;
+    TheWorkedCalls workedCalls;
 
-	Calls call;
-	QString  callString;
-	int i;
+    Calls call;
+    QString  callString;
+    int i;
 
 //	New functions and optimizations
 
-	typedef QMap<QString, int> QRZMap;  	// To map QRZ/first QSO Number
-	QRZMap qrzMap;				// Prefix/Entity
-	QRZMap::Iterator itQR;			//Iterator
+    typedef QMap<QString, int> QRZMap;  	// To map QRZ/first QSO Number
+    QRZMap qrzMap;				// Prefix/Entity
+    QRZMap::Iterator itQR;			//Iterator
 
 
 };
